@@ -1,412 +1,548 @@
-<?xml version="1.0" ?><!DOCTYPE TS><TS language="fr" version="2.1">
+<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="fr">
 <context>
     <name>MainWindow</name>
     <message>
         <location filename="mainwindow.ui" line="14"/>
+        <location filename="ui_mainwindow.h" line="623"/>
         <source>Program_Name</source>
         <translation>Program_Name</translation>
     </message>
     <message>
         <location filename="mainwindow.ui" line="46"/>
+        <location filename="ui_mainwindow.h" line="625"/>
         <source>Quit application</source>
         <translation>Quitter l’application</translation>
     </message>
     <message>
         <location filename="mainwindow.ui" line="49"/>
+        <location filename="ui_mainwindow.h" line="627"/>
         <source>Close</source>
         <translation>Quitter</translation>
     </message>
     <message>
-        <location filename="mainwindow.ui" line="56"/>
+        <location filename="mainwindow.ui" line="55"/>
+        <location filename="ui_mainwindow.h" line="629"/>
         <source>Alt+N</source>
         <translation>Alt+N</translation>
     </message>
     <message>
-        <location filename="mainwindow.ui" line="88"/>
+        <location filename="mainwindow.ui" line="87"/>
+        <location filename="ui_mainwindow.h" line="632"/>
         <source>Display help </source>
         <translation>Afficher l’aide </translation>
     </message>
     <message>
-        <location filename="mainwindow.ui" line="91"/>
+        <location filename="mainwindow.ui" line="90"/>
+        <location filename="ui_mainwindow.h" line="634"/>
         <source>Help</source>
         <translation>Aide</translation>
     </message>
     <message>
-        <location filename="mainwindow.ui" line="98"/>
+        <location filename="mainwindow.ui" line="96"/>
+        <location filename="ui_mainwindow.h" line="636"/>
         <source>Alt+H</source>
         <translation>Alt+H</translation>
     </message>
     <message>
-        <location filename="mainwindow.ui" line="114"/>
+        <location filename="mainwindow.ui" line="112"/>
+        <location filename="ui_mainwindow.h" line="638"/>
         <source>Back</source>
         <translation>Précédent</translation>
     </message>
     <message>
-        <location filename="mainwindow.ui" line="172"/>
+        <location filename="mainwindow.ui" line="169"/>
+        <location filename="ui_mainwindow.h" line="640"/>
         <source>Next</source>
         <translation>Suivant</translation>
     </message>
     <message>
-        <location filename="mainwindow.ui" line="198"/>
+        <location filename="mainwindow.ui" line="194"/>
+        <location filename="ui_mainwindow.h" line="645"/>
         <source>About this application</source>
         <translation>À propos de cette application</translation>
     </message>
     <message>
-        <location filename="mainwindow.ui" line="201"/>
+        <location filename="mainwindow.ui" line="197"/>
+        <location filename="ui_mainwindow.h" line="647"/>
         <source>About...</source>
         <translation>À propos...</translation>
     </message>
     <message>
-        <location filename="mainwindow.ui" line="208"/>
+        <location filename="mainwindow.ui" line="203"/>
+        <location filename="ui_mainwindow.h" line="649"/>
         <source>Alt+B</source>
         <translation>Alt+B</translation>
     </message>
     <message>
-        <location filename="mainwindow.ui" line="239"/>
-        <location filename="mainwindow.cpp" line="462"/>
-        <location filename="mainwindow.cpp" line="481"/>
+        <location filename="mainwindow.ui" line="219"/>
+        <location filename="ui_mainwindow.h" line="651"/>
+        <source>View Log</source>
+        <translation>Afficher le journal</translation>
+    </message>
+    <message>
+        <location filename="mainwindow.ui" line="253"/>
+        <location filename="mainwindow.cpp" line="527"/>
+        <location filename="mainwindow.cpp" line="550"/>
+        <location filename="ui_mainwindow.h" line="652"/>
         <source>Select ISO</source>
         <translation>Choisir une image ISO</translation>
     </message>
     <message>
-        <location filename="mainwindow.ui" line="250"/>
+        <location filename="mainwindow.ui" line="263"/>
+        <location filename="ui_mainwindow.h" line="653"/>
         <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Select Target USB Device&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
         <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Choix du périphérique USB cible&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
     </message>
     <message>
-        <location filename="mainwindow.ui" line="260"/>
+        <location filename="mainwindow.ui" line="273"/>
+        <location filename="ui_mainwindow.h" line="654"/>
         <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Select ISO file&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
         <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Choix du fichier ISO&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
     </message>
     <message>
-        <location filename="mainwindow.ui" line="289"/>
+        <location filename="mainwindow.ui" line="302"/>
+        <location filename="ui_mainwindow.h" line="655"/>
         <source>Advanced Options</source>
         <translation>Options avancées</translation>
     </message>
     <message>
-        <location filename="mainwindow.ui" line="307"/>
+        <location filename="mainwindow.ui" line="320"/>
+        <location filename="ui_mainwindow.h" line="656"/>
         <source>Make the ext4 filesystem even if one exists</source>
         <translation>Créer le système de fichiers ext4 même s’il en existe déjà un</translation>
     </message>
     <message>
-        <location filename="mainwindow.ui" line="314"/>
+        <location filename="mainwindow.ui" line="327"/>
+        <location filename="ui_mainwindow.h" line="657"/>
         <source>Save the original boot directory when updating a live-usb</source>
         <translation>Conserver le répertoire boot originel lors de la mise à jour du live-usb</translation>
     </message>
     <message>
-        <location filename="mainwindow.ui" line="321"/>
+        <location filename="mainwindow.ui" line="334"/>
+        <location filename="ui_mainwindow.h" line="659"/>
         <source>Use gpt partitioning instead of msdos</source>
         <translation>Utilise le partitionnement gpt à la place de msdos</translation>
     </message>
     <message>
-        <location filename="mainwindow.ui" line="324"/>
+        <location filename="mainwindow.ui" line="337"/>
+        <location filename="ui_mainwindow.h" line="661"/>
         <source>GPT partitioning</source>
         <translation>Partitionnement GPT</translation>
     </message>
     <message>
-        <location filename="mainwindow.ui" line="331"/>
+        <location filename="mainwindow.ui" line="344"/>
+        <location filename="ui_mainwindow.h" line="662"/>
         <source>Update (only update an existing live-usb)</source>
         <translation>Mettre à jour (met uniquement à jour un live-usb existant)</translation>
     </message>
     <message>
-        <location filename="mainwindow.ui" line="338"/>
+        <location filename="mainwindow.ui" line="351"/>
+        <location filename="ui_mainwindow.h" line="664"/>
         <source>Don&apos;t replace syslinux files</source>
         <translation>Ne pas remplacer les fichiers syslinux</translation>
     </message>
     <message>
-        <location filename="mainwindow.ui" line="341"/>
+        <location filename="mainwindow.ui" line="354"/>
+        <location filename="ui_mainwindow.h" line="666"/>
         <source>Keep syslinux files</source>
         <translation>Conserver les fichiers syslinux</translation>
     </message>
     <message>
-        <location filename="mainwindow.ui" line="348"/>
+        <location filename="mainwindow.ui" line="361"/>
+        <location filename="ui_mainwindow.h" line="667"/>
         <source>Ignore USB/removable check</source>
         <translation>Ignorer les vérifications USB/Démontable</translation>
     </message>
     <message>
-        <location filename="mainwindow.ui" line="355"/>
+        <location filename="mainwindow.ui" line="368"/>
+        <location filename="ui_mainwindow.h" line="668"/>
         <source>Temporarily disable automounting</source>
         <translation>Désactiver temporairement le montage automatique</translation>
     </message>
     <message>
-        <location filename="mainwindow.ui" line="365"/>
+        <location filename="mainwindow.ui" line="378"/>
+        <location filename="ui_mainwindow.h" line="672"/>
         <source>Set pmbr_boot disk flag (won&apos;t boot via UEFI)</source>
         <translation>Activer le marqueur pmbr_boot sur le disque (pas de démarrage via UEFI)</translation>
     </message>
     <message>
-        <location filename="mainwindow.ui" line="372"/>
+        <location filename="mainwindow.ui" line="385"/>
+        <location filename="ui_mainwindow.h" line="673"/>
         <source>Don&apos;t use fuseiso to mount iso files</source>
         <translation>N’utilisez pas fuseiso pour monter des images iso</translation>
     </message>
     <message>
-        <location filename="mainwindow.ui" line="398"/>
+        <location filename="mainwindow.ui" line="411"/>
+        <location filename="ui_mainwindow.h" line="674"/>
         <source>Size of ESP (uefi) partition:</source>
         <translation>Taille de la partition ESP (uefi) :</translation>
     </message>
     <message>
-        <location filename="mainwindow.ui" line="418"/>
+        <location filename="mainwindow.ui" line="431"/>
+        <location filename="ui_mainwindow.h" line="675"/>
         <source>Verbosity (less to more):</source>
         <translation>Verbosité (du moins au plus) :</translation>
     </message>
     <message>
-        <location filename="mainwindow.ui" line="457"/>
+        <location filename="mainwindow.ui" line="470"/>
+        <location filename="ui_mainwindow.h" line="676"/>
         <source>vfat</source>
         <translation>vfat</translation>
     </message>
     <message>
-        <location filename="mainwindow.ui" line="462"/>
+        <location filename="mainwindow.ui" line="475"/>
+        <location filename="ui_mainwindow.h" line="677"/>
         <source>exfat</source>
         <translation>exfat</translation>
     </message>
     <message>
-        <location filename="mainwindow.ui" line="467"/>
+        <location filename="mainwindow.ui" line="480"/>
+        <location filename="ui_mainwindow.h" line="678"/>
         <source>ext4</source>
         <translation>ext4</translation>
     </message>
     <message>
-        <location filename="mainwindow.ui" line="472"/>
+        <location filename="mainwindow.ui" line="485"/>
+        <location filename="ui_mainwindow.h" line="679"/>
         <source>ntfs</source>
         <translation>ntfs</translation>
     </message>
     <message>
-        <location filename="mainwindow.ui" line="493"/>
+        <location filename="mainwindow.ui" line="509"/>
+        <location filename="ui_mainwindow.h" line="681"/>
         <source>Make separate data partition (percent)</source>
         <translation>Créer une partition de données séparée (pourcent) </translation>
     </message>
     <message>
-        <location filename="mainwindow.ui" line="500"/>
+        <location filename="mainwindow.ui" line="516"/>
+        <location filename="ui_mainwindow.h" line="682"/>
         <source>Format</source>
         <translation>Format</translation>
     </message>
     <message>
-        <location filename="mainwindow.ui" line="510"/>
+        <location filename="mainwindow.ui" line="526"/>
+        <location filename="ui_mainwindow.h" line="683"/>
         <source>Refresh drive list</source>
         <translation>Rafraîchir la liste des lecteurs</translation>
     </message>
     <message>
-        <location filename="mainwindow.ui" line="524"/>
-        <location filename="mainwindow.cpp" line="407"/>
+        <location filename="mainwindow.ui" line="539"/>
+        <location filename="mainwindow.cpp" line="488"/>
+        <location filename="ui_mainwindow.h" line="684"/>
         <source>Show advanced options</source>
         <translation>Afficher les options avancées</translation>
     </message>
     <message>
-        <location filename="mainwindow.ui" line="544"/>
+        <location filename="mainwindow.ui" line="558"/>
+        <location filename="ui_mainwindow.h" line="685"/>
         <source>Mode</source>
         <translation>Mode</translation>
     </message>
     <message>
-        <location filename="mainwindow.ui" line="559"/>
-        <source>Full-featured mode - writable LiveUSB</source>
-        <translation>Mode complet - LiveUSB inscriptible</translation>
+        <location filename="mainwindow.ui" line="573"/>
+        <location filename="ui_mainwindow.h" line="686"/>
+        <source>Full-featured mode - writable Li&amp;veUSB</source>
+        <translation>Mode complet - Li&amp;veUSB accessible en écriture</translation>
     </message>
     <message>
-        <location filename="mainwindow.ui" line="569"/>
+        <location filename="mainwindow.ui" line="583"/>
+        <location filename="ui_mainwindow.h" line="688"/>
         <source>Read-only, cannot be used with persistency</source>
         <translation>Lecture seule, incompatible avec la persistance</translation>
     </message>
     <message>
-        <location filename="mainwindow.ui" line="572"/>
-        <source>Image mode - read-only LiveUSB (dd)</source>
-        <translation>Mode image - LiveUSB en lecture seule (dd)</translation>
+        <location filename="mainwindow.ui" line="586"/>
+        <location filename="ui_mainwindow.h" line="690"/>
+        <source>Image &amp;mode - read-only LiveUSB (dd)</source>
+        <translation>&amp;Mode image - LiveUSB (dd) en lecture seule</translation>
     </message>
     <message>
-        <location filename="mainwindow.ui" line="586"/>
+        <location filename="mainwindow.ui" line="599"/>
+        <location filename="ui_mainwindow.h" line="691"/>
         <source>For distros other than antiX/MX use image mode (dd).</source>
         <translation>Pour une distribution autre que antiX/MX, utilisez le mode image (dd).</translation>
     </message>
     <message>
-        <location filename="mainwindow.ui" line="634"/>
+        <location filename="mainwindow.ui" line="647"/>
+        <location filename="ui_mainwindow.h" line="692"/>
         <source>Options</source>
         <translation>Options</translation>
     </message>
     <message>
-        <location filename="mainwindow.ui" line="669"/>
+        <location filename="mainwindow.ui" line="685"/>
+        <location filename="ui_mainwindow.h" line="693"/>
         <source>Percent of USB-device to use:</source>
         <translation>Part du périphérique USB utiisé (%) :</translation>
     </message>
     <message>
-        <location filename="mainwindow.ui" line="676"/>
+        <location filename="mainwindow.ui" line="692"/>
+        <location filename="ui_mainwindow.h" line="694"/>
         <source>Label ext partition:</source>
-        <translation>Etiquette de la partition</translation>
+        <translation>Étiquette de la partition</translation>
     </message>
     <message>
-        <location filename="mainwindow.ui" line="724"/>
+        <location filename="mainwindow.ui" line="740"/>
+        <location filename="ui_mainwindow.h" line="696"/>
         <source>Don&apos;t run commands that affect the usb device</source>
         <translation>Ne pas lancer de commande affectant le périphérique usb</translation>
     </message>
     <message>
-        <location filename="mainwindow.ui" line="727"/>
+        <location filename="mainwindow.ui" line="743"/>
+        <location filename="ui_mainwindow.h" line="698"/>
         <source>Dry run (no change to system)</source>
         <translation>Test (aucune modification du système)</translation>
     </message>
     <message>
-        <location filename="mainwindow.ui" line="734"/>
+        <location filename="mainwindow.ui" line="750"/>
+        <location filename="ui_mainwindow.h" line="700"/>
         <source>clone from a mounted live-usb or iso-file.</source>
         <translation>Cloner à partir d’un usb-live monté ou d’un fichier iso</translation>
     </message>
     <message>
-        <location filename="mainwindow.ui" line="737"/>
-        <source>Clone an existing live system</source>
-        <translation>Cloner un système live existant</translation>
+        <location filename="mainwindow.ui" line="753"/>
+        <source>Clone a mounted live system</source>
+        <translation>Cloner un système live monté</translation>
     </message>
     <message>
-        <location filename="mainwindow.ui" line="744"/>
+        <location filename="mainwindow.ui" line="760"/>
+        <location filename="ui_mainwindow.h" line="704"/>
         <source>Set up to boot from an encrypted partition, will prompt for pass phrase on first boot</source>
         <translation>Organise le démarrage depuis une partition chiffrée. Exigera une phrase de passe au premier démarrage.</translation>
     </message>
     <message>
-        <location filename="mainwindow.ui" line="747"/>
+        <location filename="mainwindow.ui" line="763"/>
+        <location filename="ui_mainwindow.h" line="706"/>
         <source>Encrypt</source>
         <translation>Chiffrer</translation>
     </message>
     <message>
-        <location filename="mainwindow.ui" line="754"/>
+        <location filename="mainwindow.ui" line="770"/>
+        <location filename="ui_mainwindow.h" line="707"/>
         <source>Clone running live system</source>
         <translation>Cloner un système live en fonctionnement</translation>
     </message>
     <message>
-        <location filename="mainwindow.cpp" line="86"/>
-        <location filename="mainwindow.cpp" line="267"/>
-        <location filename="mainwindow.cpp" line="392"/>
+        <location filename="mainwindow.cpp" line="80"/>
+        <source>Confirmation</source>
+        <translation>Confirmation</translation>
+    </message>
+    <message>
+        <location filename="mainwindow.cpp" line="81"/>
+        <source>Target device %1 is larger than %2 GB. Do you wish to proceed?</source>
+        <translation>Le périphérique cible %1 fait plus de %2 Go. Voulez-vous continuer ?</translation>
+    </message>
+    <message>
+        <location filename="mainwindow.cpp" line="118"/>
+        <location filename="mainwindow.cpp" line="336"/>
+        <location filename="mainwindow.cpp" line="472"/>
         <source>Failure</source>
         <translation>Échec</translation>
     </message>
     <message>
-        <location filename="mainwindow.cpp" line="86"/>
+        <location filename="mainwindow.cpp" line="119"/>
         <source>Source and destination are on the same device, please select again.</source>
         <translation>La source est la destination sont sur le même périphérique, veuillez recommencer la sélection.</translation>
     </message>
     <message>
-        <location filename="mainwindow.cpp" line="111"/>
+        <location filename="mainwindow.cpp" line="150"/>
         <source>Writing %1 using 'dd' command to /dev/%2,
 
-Please wait until the the process is completed</source>
-        <translation>Ecriture de %1 à l’aide de la commande « dd » sur /dev/%2,
+Please wait until the process is completed</source>
+        <translation>Écriture de %1 à l’aide de la commande « dd » sur /dev/%2.
 
-Veuillez attendre la fin du processus</translation>
+Veuillez patienter jusqu’à la fin de la procédure.</translation>
     </message>
     <message>
-        <location filename="mainwindow.cpp" line="265"/>
+        <location filename="mainwindow.cpp" line="162"/>
+        <source>Live USB Maker</source>
+        <translation>Live USB Création - Live USB Maker</translation>
+    </message>
+    <message>
+        <location filename="mainwindow.cpp" line="333"/>
         <source>Success</source>
-        <translation>Réussite de l’installation</translation>
+        <translation>Installation réussie</translation>
     </message>
     <message>
-        <location filename="mainwindow.cpp" line="265"/>
+        <location filename="mainwindow.cpp" line="333"/>
         <source>LiveUSB creation successful!</source>
         <translation>Création du Live USB accomplie!</translation>
     </message>
     <message>
-        <location filename="mainwindow.cpp" line="267"/>
+        <location filename="mainwindow.cpp" line="336"/>
         <source>Error encountered in the LiveUSB creation process</source>
         <translation>Erreurs rencontrées pendant le processus de création du Live USB</translation>
     </message>
     <message>
-        <location filename="mainwindow.cpp" line="316"/>
+        <location filename="mainwindow.cpp" line="394"/>
         <source>Error</source>
         <translation>Erreur</translation>
     </message>
     <message>
-        <location filename="mainwindow.cpp" line="316"/>
+        <location filename="mainwindow.cpp" line="394"/>
         <source>Please select a USB device to write to</source>
         <translation>Veuillez choisir le périphérique USB sur lequel écrire</translation>
     </message>
     <message>
-        <location filename="mainwindow.cpp" line="319"/>
-        <location filename="mainwindow.cpp" line="475"/>
-        <source>clone</source>
-        <translation>clone</translation>
+        <location filename="mainwindow.cpp" line="397"/>
+        <source>These actions will destroy all data on 
+
+</source>
+        <translation>Ces actions supprimeront toutes les données sur 
+
+</translation>
     </message>
     <message>
-        <location filename="mainwindow.cpp" line="355"/>
+        <location filename="mainwindow.cpp" line="398"/>
+        <source>Do you wish to continue?</source>
+        <translation>Souhaitez-vous continuer ?</translation>
+    </message>
+    <message>
+        <location filename="mainwindow.cpp" line="430"/>
         <source>About %1</source>
         <translation>À propos %1</translation>
     </message>
     <message>
-        <location filename="mainwindow.cpp" line="356"/>
+        <location filename="mainwindow.cpp" line="431"/>
         <source>Version: </source>
         <translation>Version : </translation>
     </message>
     <message>
-        <location filename="mainwindow.cpp" line="357"/>
+        <location filename="mainwindow.cpp" line="433"/>
         <source>Program for creating a live-usb from an iso-file, another live-usb, a live-cd/dvd, or a running live system.</source>
         <translation>Programme de création d’un live-usb à partir d’un fichier ISO, d’un autre live-usb, d’un live-cd/dvd ou d’un système live en fonctionnement.</translation>
     </message>
     <message>
-        <location filename="mainwindow.cpp" line="359"/>
+        <location filename="mainwindow.cpp" line="436"/>
         <source>Copyright (c) MX Linux</source>
         <translation>Copyright (c) MX Linux</translation>
     </message>
     <message>
-        <location filename="mainwindow.cpp" line="360"/>
+        <location filename="mainwindow.cpp" line="437"/>
         <source>%1 License</source>
         <translation>%1 Licence</translation>
     </message>
     <message>
-        <location filename="mainwindow.cpp" line="368"/>
+        <location filename="mainwindow.cpp" line="444"/>
         <source>%1 Help</source>
         <translation>%1 Aide</translation>
     </message>
     <message>
-        <location filename="mainwindow.cpp" line="379"/>
+        <location filename="mainwindow.cpp" line="452"/>
         <source>Select an ISO file to write to the USB drive</source>
         <translation>Choisir le fichier ISO qui sera gravé sur le périphérique USB</translation>
     </message>
     <message>
-        <location filename="mainwindow.cpp" line="387"/>
-        <location filename="mainwindow.cpp" line="458"/>
+        <location filename="mainwindow.cpp" line="453"/>
+        <source>ISO Files (*.iso);;All Files (*.*)</source>
+        <translation>Fichiers ISO (*.iso);;Tous les fichiers (*.*)</translation>
+    </message>
+    <message>
+        <location filename="mainwindow.cpp" line="463"/>
+        <location filename="mainwindow.cpp" line="522"/>
         <source>Select Source Directory</source>
         <translation>Choix du répertoire source</translation>
     </message>
     <message>
-        <location filename="mainwindow.cpp" line="392"/>
+        <location filename="mainwindow.cpp" line="473"/>
         <source>Could not find %1/antiX/linuxfs file</source>
         <translation>Impossible de trouver le fichier %1/antiX/linuxfs</translation>
     </message>
     <message>
-        <location filename="mainwindow.cpp" line="413"/>
+        <location filename="mainwindow.cpp" line="494"/>
         <source>Hide advanced options</source>
         <translation>Cacher les options avancées</translation>
     </message>
     <message>
-        <location filename="mainwindow.cpp" line="457"/>
-        <location filename="mainwindow.cpp" line="473"/>
+        <location filename="mainwindow.cpp" line="521"/>
+        <location filename="mainwindow.cpp" line="540"/>
         <source>Select Source</source>
         <translation>Choisir la source</translation>
     </message>
     <message>
-        <location filename="mainwindow.cpp" line="461"/>
-        <location filename="mainwindow.cpp" line="479"/>
+        <location filename="mainwindow.cpp" line="526"/>
+        <location filename="mainwindow.cpp" line="548"/>
         <source>Select ISO file</source>
         <translation>Choisir le fichier ISO</translation>
     </message>
+    <message>
+        <location filename="mainwindow.cpp" line="542"/>
+        <source>clone</source>
+        <translation>clone</translation>
+    </message>
+    <message>
+        <location filename="mainwindow.cpp" line="609"/>
+        <source>Could not find a log file at: </source>
+        <translation>Impossible de trouver un fichier journal dans : </translation>
+    </message>
+    <message>
+        <location filename="ui_mainwindow.h" line="702"/>
+        <source>Clone an existing live system</source>
+        <translation>Cloner un système live existant</translation>
+    </message>
 </context>
 <context>
-    <name>QApplication</name>
+    <name>QObject</name>
     <message>
-        <location filename="about.cpp" line="32"/>
+        <location filename="about.cpp" line="70"/>
         <source>License</source>
         <translation>Licence</translation>
     </message>
     <message>
-        <location filename="about.cpp" line="33"/>
-        <location filename="about.cpp" line="43"/>
+        <location filename="about.cpp" line="71"/>
+        <location filename="about.cpp" line="81"/>
         <source>Changelog</source>
         <translation>Journal des modifications</translation>
     </message>
     <message>
-        <location filename="about.cpp" line="34"/>
+        <location filename="about.cpp" line="72"/>
         <source>Cancel</source>
         <translation>Annuler</translation>
     </message>
     <message>
-        <location filename="about.cpp" line="51"/>
+        <location filename="about.cpp" line="94"/>
         <source>&amp;Close</source>
-        <translation>&amp;Fermer</translation>
+        <translation>Q&amp;uitter</translation>
     </message>
     <message>
-        <location filename="main.cpp" line="75"/>
+        <location filename="main.cpp" line="54"/>
+        <source>Program for creating a live-usb from an iso-file, another live-usb, a live-cd/dvd, or a running live system.</source>
+        <translation>Programme de création d’un live-usb à partir d’un fichier ISO, d’un autre live-usb, d’un live-cd/dvd ou d’un système live en fonctionnement.</translation>
+    </message>
+    <message>
+        <location filename="main.cpp" line="58"/>
+        <source>filename</source>
+        <translation>nom de fichier</translation>
+    </message>
+    <message>
+        <location filename="main.cpp" line="58"/>
+        <source>Name of .iso file to open</source>
+        <translation>Nom du fichier .iso à ouvrir</translation>
+    </message>
+    <message>
+        <location filename="main.cpp" line="59"/>
+        <source>[filename]</source>
+        <translation>[nom de fichier]</translation>
+    </message>
+    <message>
+        <location filename="main.cpp" line="87"/>
+        <location filename="main.cpp" line="96"/>
+        <source>Error</source>
+        <translation>Erreur</translation>
+    </message>
+    <message>
+        <location filename="main.cpp" line="88"/>
+        <source>You seem to be logged in as root, please log out and log in as normal user to use this program.</source>
+        <translation>Vous êtes apparemment connecté en tant que root, veuillez vous déconnecter et vous connecter en tant qu’utilisateur normal pour utiliser ce programme.</translation>
+    </message>
+    <message>
+        <location filename="main.cpp" line="96"/>
         <source>You must run this program as root.</source>
-        <translation>Vous devez lancer cette application avec les droits administrateur.</translation>
+        <translation>Vous devez exécuter cette application en tant que root.</translation>
+    </message>
+    <message>
+        <location filename="main.cpp" line="111"/>
+        <source>version:</source>
+        <translation>version :</translation>
     </message>
 </context>
 </TS>
\ No newline at end of file
